@@ -227,6 +227,17 @@ applet_fill (PanelApplet *applet)
                                            applet_menu_verbs,
                                            dd);
 
+	if (panel_applet_get_locked_down (PANEL_APPLET (applet))) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/Properties",
+					      "hidden", "1",
+					      NULL);
+	}
+
 	component = panel_applet_get_popup_component (PANEL_APPLET (applet));
 
 	tmp_path = gnome_is_program_in_path ("eject");
